############################################################################
#
# Lennard-Jones Cluster problem
# as described in
#   M. Locatelli and F. Schoen, "Fast global optimization of difficult
#   Lennard-Jones clusters", Computational optimization and applications,
#   vol. 21, pp 55-70, 2002
#
# Coded for AMPL by: aivaz@dps.uminho.pt
# Minho University, Portugal
# 29 September 2005
############################################################################

# parameters
param n := 98;
param p := 4;
param mu := 0.3;

# variables
var x{1..3,1..n};
var v{i in 1..n, j in 1..i-1} = sqrt(sum {k in 1..3} (x[k,i]-x[k,j])^2);
# avoid division by 0
var w{i in 1..n, j in 1..i-1} = if v[i,j]=0 then 1e-20 else v[i,j];


# objective function, minimization problem
minimize fx:
    sum {i in 1..n} ( sum {j in 1..i-1} (1/(w[i,j]^(2*p))
                            -(2/(w[i,j]^p))+
                            mu*w[i,j]));

subject to bounds {k in 1..3, i in 1..n}:
    -1 <= x[k,i] <= 1;


include solver.mod;

display fx;
display x;
