############################################################################
#
# Least Median Squares problem
# as described in
#   M. Mongeau, H. Karsenty, V. Rouge, J.-B. Hiriat-Urruty, "Comparison of
#   public-domain software for black box global optimization", Optimization
#   Methods and Software, 13(3), pp. 203-226, 2000
#
# Coded for AMPL by: aivaz@dps.uminho.pt
# Minho University, Portugal
# 29 September 2005
############################################################################

# Include stats.dll as external dynamic library (ampl -i stats.dll)
function median;

# parameters
param p := 2;
param n := 25;
param x{1..n,1..p};
param y{1..n};


# variables
var theta{1..p};
var b;
var r{i in 1..n} = y[i]-sum {j in 1..p} (x[i,j]*theta[j]) - b;


# objective function, minimization problem
minimize fx:
    median({i in 1..n} r[i]^2);

subject to bounds {i in 1..p}:
    0 <= theta[i] <= 3;

subject to bbound:
    -10 <= b <= 10;

data;

param x: 1 2 :=
1   7   5.60
2   3   2.20
3   3   3.40
4   4   0.80
5   6   1.50
6   7   3.30
7   2   1.10
8   7   2.10
9   30  14.60
10  5   6.05
11  16  6.88
12  10  2.15
13  4   2.55
14  6   4.62
15  9   4.48
16  10  7.76
17  6   2.00
18  7   1.32
19  3   0.36
20  17  7.70
21  10  1.40
22  26  8.10
23  9   4.50
24  8   6.35
25  4   1.50; 

param y :=
1   16.68
2   11.50
3   12.03
4   14.88
5   13.75
6   18.11
7   8.00
8   17.83
9   79.24
10  21.50
11  40.33
12  21.00
13  13.50
14  19.75
15  24.00
16  29.00
17  15.35
18  19.00
19  9.50
20  35.10
21  17.90
22  52.32
23  18.75
24  19.83
25  10.75;

include solver.mod;

display fx;
display theta;
display b;
